belso.translator.utils package — belso 0.0.1 documentation

# belso.translator.utils package

## Submodules

## belso.translator.utils.detecting module

belso.translator.utils.detecting.detect_schema_format(schema)

  Detect the format of the input schema.

  Return type:

    `str`

  ### Args

  - schema: the schema to detect.

  ### Returns

  - str: the detected format as a string.

## Module contents

belso.translator.utils.detect_schema_format(schema)

  Detect the format of the input schema.

  Return type:

    `str`

  ### Args

  - schema: the schema to detect.

  ### Returns

  - str: the detected format as a string.